==============
RadQy
==============

RadQy is a quality assurance and checking tool for quantitative assessment of magnetic resonance imaging (MRI) and computed tomography (CT) data.

Installation
------------

To install the package, use pip:

.. code-block:: bash

    pip install radqy

